<?php // $Id$

/**
 * Form callback for the social network administration page.
 */
function slinky_share_admin(&$form_state) {
  // Add JavaScript to hide form elements.
  drupal_add_js(drupal_get_path('module', 'slinky_share') .'/js/slinky_share.js');

  $form = array();

  // Add vertical_tabs support, if that module is installed.
  $form['#pre_render'][] = 'vertical_tabs_form_pre_render';

  // Node types.
  $form['types'] = array(
    '#type' => 'fieldset',
    '#title' => t('Content types'),
    '#description' => t('Define which content types will be shareable on social networking sites.'),
  );
  $form['types']['slinky_share_node_types'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Content types'),
    '#options' => node_get_types('names'),
    '#default_value' => variable_get('slinky_share_node_types', array()), 
    '#description' => t('The content types that should include sharing functionality.'),
  );

  // Show on node teaser?
/*
  $form['types']['slinky_share_node_teaser'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show links on node teaser?'),
    '#default_value' => variable_get('slinky_share_node_teaser', 0),
  );
*/

  // Show on which build modes? 
  $form['types']['slinky_share_build_modes'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Show links on?'),
    '#options' => slinky_share_build_modes(), 
    '#default_value' => variable_get('slinky_share_build_modes', array()),
  );

  // Icon and URL settings.
  $form['presets'] = array(
    '#type' => 'fieldset',
    '#title' => t('Icon and URL presets'),
    '#description' => t(''),
  );
  
  // Icon preset.
  $form['presets']['slinky_share_preset'] = array(
    '#type' => 'select',
    '#title' => t('Icon presets'),
    '#options' => slinky_preset_names(),
    '#default_value' => variable_get('slinky_share_preset', 'default'), 
  );

  global $base_url;
  $form['presets']['slinky_base_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Base URL for share links.'),
    '#default_value' => variable_get('slinky_base_url', $base_url),
    '#description' => t('This is usually the URL for this site.  If you have a shorter version that might fit better in a character limit, you can include that alternative here.'),
  );

  // Link settings for each network.
  $form['slinky_share_links'] = array(
    '#type' => 'fieldset',
    '#title' => t('Social networks'),
    '#description' => t(''),
    '#tree' => TRUE,
  );

  // Get pre-configured links.
  $links = variable_get('slinky_share_links', array());
  $slinky_links = slinky_links();

  foreach ($slinky_links as $key => $link) {
    if (isset($link['share']) && !isset($links[$key])) {
      $links[$key] = $link['share'];
    }
  }

  foreach ($links as $key => $link) {
    $form['slinky_share_links'][$key] = array(
      '#type' => 'fieldset',
      '#attributes' => array('class' => 'social-network-form'),
    );
    $form['slinky_share_links'][$key]['enabled'] = array(
      '#type' => 'checkbox',
      '#title' => $link['title'],
      '#default_value' => $link['enabled'],
    );
    $form['slinky_share_links'][$key]['title'] = array(
      '#type' => 'textfield',
      '#title' => t('Link title'),
      '#default_value' => $link['title'],
      '#prefix' => '<div class="form-hideable">',
    );
    $form['slinky_share_links'][$key]['href'] = array(
      '#type' => 'textarea',
      '#title' => t('Link or share code'),
      '#default_value' => $link['href'],
      '#suffix' => '</div>',
    );
  }

  $form['slinky_share_links']['tokens'] = array(
    '#type' => 'fieldset',
    '#title' => t('Available tokens'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['slinky_share_links']['tokens']['tokens'] = array(
    '#type' => 'markup',
    '#value' => theme('token_help', 'node'), 
  );

  // Add my own submit handler to clean up some variables.
  $form['#submit'] = array('slinky_share_admin_submit');

  // Use the system_settings_form functionality.
  return system_settings_form($form);
}

/**
 * Form submit handler for slinky_share_admin().
 */
function slinky_share_admin_submit($form, &$form_state) {
  // Save an array_filter()'ed version of the node_types value.
  $node_types = array_filter($form_state['values']['slinky_share_node_types']);
  variable_set('slinky_share_node_types', $node_types);
  unset($form_state['values']['slinky_share_node_types']);

  // Create and save a custom value for $slinky_share_links.
  $slinky_links = array();
  foreach($form_state['values']['slinky_share_links'] as $key => $info) {
    $slinky_links[$key] = $info;
  }
  variable_set('slinky_share_links', $slinky_links);
  unset($form_state['values']['slinky_share_links']);
}
